Déplacement de Knight dans les alliages - Archive ouverte HAL
Author: Jacques Friedel
Description: Des calculs récents de la densité électronique dans les alliages prévoient que le déplacement de Knight des noyaux de la matrice n'est pratiquement pas affecté par la substitution d'atomes en soluté, même à assez fortes concentrations.
Keywords: alloys;nuclear magnetic resonance
Date: 1955

Accéder directement au contenu
Loading...
Article Dans Une Revue Journal de Physique et le Radium Année : 1955

## Déplacement de Knight dans les alliages

Jacques Friedel
Jacques Friedel

- Fonction : Auteur

#### Résumé

Des calculs récents de la densité électronique dans les alliages prévoient que le déplacement de Knight des noyaux de la matrice n'est pratiquement pas affecté par la substitution d'atomes en soluté, même à assez fortes concentrations.

#### Mots clés

alloys nuclear magnetic resonance

#### Domaines

Articles anciens
Fichier principal
ajp-jphysrad_1955_16_6_444_0.pdf (273.22 Ko) Télécharger le fichier

Origine | Accord explicite pour ce dépôt

Loading...

Archives Journal de Physique : Connectez-vous pour contacter le contributeur

https://hal.science/jpa-00235190

Soumis le : lundi 4 février 2008-08:00:00

Dernière modification le : mercredi 20 mars 2024-10:08:23

Archivage à long terme le : jeudi 6 mai 2010-15:33:11

Télécharger pour visualiser

### Dates et versions

jpa-00235190 , version 1 (04-02-2008)

### Identifiants

- HAL Id : jpa-00235190 , version 1
- DOI : 10.1051/jphysrad:01955001606044400

### Citer

Jacques Friedel. Déplacement de Knight dans les alliages. Journal de Physique et le Radium, 1955, 16 (6), pp.444-445. ⟨10.1051/jphysrad:01955001606044400⟩. ⟨jpa-00235190⟩

### Exporter

BibTeX XML-TEI Dublin Core DC Terms EndNote DataCite

### Collections

AJP
195 Consultations
83 Téléchargements

### Altmetric

### Partager

Gmail Mastodon Facebook X LinkedIn More